@@ -152,4 +152,4 @@
};
Module.setStatus('Downloading...');
-
\ No newline at end of file
+
diff --git a/file.c b/file.c
index 867ff563a7..5e415f40f0 100644
--- a/file.c
+++ b/file.c
@@ -83,7 +83,7 @@ static void patch_rom(uint8_t **buf, ssize_t *size)
}
else
{
- RARCH_LOG("Did not find a valid ROM patch.\n");
+ RARCH_LOG("Did not find a valid content patch.\n");
return;
}
@@ -93,14 +93,14 @@ static void patch_rom(uint8_t **buf, ssize_t *size)
uint8_t *patched_rom = (uint8_t*)malloc(target_size);
if (!patched_rom)
{
- RARCH_ERR("Failed to allocate memory for patched ROM ...\n");
+ RARCH_ERR("Failed to allocate memory for patched content ...\n");
goto error;
}
err = func((const uint8_t*)patch_data, patch_size, ret_buf, ret_size, patched_rom, &target_size);
if (err == PATCH_SUCCESS)
{
- RARCH_LOG("ROM patched successfully (%s).\n", patch_desc);
+ RARCH_LOG("Content patched successfully (%s).\n", patch_desc);
success = true;
}
else
@@ -340,21 +340,21 @@ static bool load_content(const struct retro_subsystem_info *special, const struc
if (require_rom && !*path)
{
- RARCH_LOG("libretro core requires a ROM, but none were provided.\n");
+ RARCH_LOG("libretro core requires content, but nothing was provided.\n");
ret = false;
goto end;
}
info[i].path = *path ? path : NULL;
- if (!need_fullpath && *path) // Load the ROM into memory.
+ if (!need_fullpath && *path) // Load the content into memory.
{
- RARCH_LOG("Loading ROM file: %s.\n", path);
- // First ROM is significant, attempt to do patching, CRC checking, etc ...
+ RARCH_LOG("Loading content file: %s.\n", path);
+ // First content file is significant, attempt to do patching, CRC checking, etc ...
long size = i == 0 ? read_rom_file(path, (void**)&info[i].data) : read_file(path, (void**)&info[i].data);
if (size < 0)
{
- RARCH_ERR("Could not read ROM file \"%s\".\n", path);
+ RARCH_ERR("Could not read content file \"%s\".\n", path);
ret = false;
goto end;
}
@@ -362,7 +362,7 @@ static bool load_content(const struct retro_subsystem_info *special, const struc
info[i].size = size;
}
else
- RARCH_LOG("ROM loading skipped. Implementation will load it on its own.\n");
+ RARCH_LOG("Content loading skipped. Implementation will load it on its own.\n");
}
if (special)
@@ -467,7 +467,7 @@ bool init_rom_file(void)
if (!zlib_extract_first_rom(temporary_content, sizeof(temporary_content), valid_ext,
*g_settings.extraction_directory ? g_settings.extraction_directory : NULL))
{
- RARCH_ERR("Failed to extract ROM from zipped file: %s.\n", temporary_content);
+ RARCH_ERR("Failed to extract content from zipped file: %s.\n", temporary_content);
string_list_free(content);
return false;
}
diff --git a/history.h b/history.h
index ea8681e91f..6a3e36f3ab 100644
--- a/history.h
+++ b/history.h
@@ -13,8 +13,8 @@
* If not, see .
*/
-#ifndef ROM_HISTORY_H__
-#define ROM_HISTORY_H__
+#ifndef CONTENT_HISTORY_H__
+#define CONTENT_HISTORY_H__
#include
diff --git a/libretro.h b/libretro.h
index e06e30a0ac..15c92e98b5 100755
--- a/libretro.h
+++ b/libretro.h
@@ -784,11 +784,11 @@ struct retro_subsystem_memory_info
struct retro_subsystem_rom_info
{
- const char *desc; // Describes what the ROM is (SGB bios, GB rom, etc).
+ const char *desc; // Describes what the content is (SGB bios, GB rom, etc).
const char *valid_extensions; // Same definition as retro_get_system_info().
bool need_fullpath; // Same definition as retro_get_system_info().
bool block_extract; // Same definition as retro_get_system_info().
- bool required; // This is set if the ROM is required to load a game. If this is set to false, a zeroed-out retro_game_info can be passed.
+ bool required; // This is set if the content is required to load a game. If this is set to false, a zeroed-out retro_game_info can be passed.
// Content can have multiple associated persistent memory types (retro_get_memory()).
const struct retro_subsystem_memory_info *memory;
@@ -804,9 +804,9 @@ struct retro_subsystem_info
// This identifier can be used for command-line interfaces, etc.
const char *ident;
- // Infos for each ROM. The first entry is assumed to be the "most significant" ROM for frontend purposes.
- // E.g. with Super GameBoy, the first ROM should be the GameBoy ROM, as it is the most "significant" ROM to a user.
- // If a frontend creates new file paths based on the ROM used (e.g. savestates), it should use the path for the first ROM to do so.
+ // Infos for each content file. The first entry is assumed to be the "most significant" content for frontend purposes.
+ // E.g. with Super GameBoy, the first content should be the GameBoy ROM, as it is the most "significant" content to a user.
+ // If a frontend creates new file paths based on the content used (e.g. savestates), it should use the path for the first ROM to do so.
const struct retro_subsystem_rom_info *roms;
unsigned num_roms; // Number of content files associated with a subsystem.
@@ -1290,7 +1290,7 @@ struct retro_system_info
// This is typically set to true for libretro implementations that must load from file.
// Implementations should strive for setting this to false, as it allows the frontend to perform patching, etc.
- bool block_extract; // If true, the frontend is not allowed to extract any archives before loading the real ROM.
+ bool block_extract; // If true, the frontend is not allowed to extract any archives before loading the real content.
// Necessary for certain libretro implementations that load games from zipped archives.
};
diff --git a/retroarch.c b/retroarch.c
index 14bda2ee77..137adcdd68 100644
--- a/retroarch.c
+++ b/retroarch.c
@@ -771,7 +771,7 @@ static void print_help(void)
puts("\t-L/--libretro: Path to libretro implementation. Overrides any config setting.");
#endif
puts("\t--subsystem: Use a subsystem of the libretro core. Multiple content files are loaded as multiple arguments.");
- puts("\t\tIf a ROM is skipped, use a blank (\"\") command line argument");
+ puts("\t\tIf a content file is skipped, use a blank (\"\") command line argument");
puts("\t\tContent must be loaded in an order which depends on the particular subsystem used.");
puts("\t\tSee verbose log output to learn how a particular subsystem wants content to be loaded.");
@@ -809,9 +809,9 @@ static void print_help(void)
puts("\t--size: Overrides output video size when recording with FFmpeg (format: WIDTHxHEIGHT).");
#endif
puts("\t-v/--verbose: Verbose logging.");
- puts("\t-U/--ups: Specifies path for UPS patch that will be applied to ROM.");
- puts("\t--bps: Specifies path for BPS patch that will be applied to ROM.");
- puts("\t--ips: Specifies path for IPS patch that will be applied to ROM.");
+ puts("\t-U/--ups: Specifies path for UPS patch that will be applied to content.");
+ puts("\t--bps: Specifies path for BPS patch that will be applied to content.");
+ puts("\t--ips: Specifies path for IPS patch that will be applied to content.");
puts("\t--no-patch: Disables all forms of content patching.");
puts("\t-D/--detach: Detach RetroArch from the running console. Not relevant for all platforms.\n");
}
diff --git a/settings.c b/settings.c
index e86d41d281..87a456d496 100644
--- a/settings.c
+++ b/settings.c
@@ -512,7 +512,7 @@ void config_set_defaults(void)
g_extern.config_save_on_exit = config_save_on_exit;
- /* Avoid reloading config on every ROM load */
+ /* Avoid reloading config on every content load */
g_extern.block_config_read = default_block_config_read;
}
diff --git a/file_extract.c b/file_extract.c
index d9c2f0a7e9..9ea8223985 100644
--- a/file_extract.c
+++ b/file_extract.c
@@ -320,7 +320,7 @@ static bool zip_extract_cb(const char *name, const uint8_t *cdata, unsigned cmod
{
struct zip_extract_userdata *data = (struct zip_extract_userdata*)userdata;
// Extract first ROM that matches our list.
const char *ext = path_get_extension(name);
if (ext && string_list_find_elem(data->ext, ext))
{
@@ -388,7 +388,7 @@ bool zlib_extract_first_rom(char *zip_path, size_t zip_path_size, const char *va
if (!userdata.found_rom)
{
- RARCH_ERR("Didn't find any ROMS that matched valid extensions for libretro implementation.\n");
+ RARCH_ERR("Didn't find any content that matched valid extensions for libretro implementation.\n");
GOTO_END_ERROR();
}
@@ -320,7 +320,7 @@ static bool zip_extract_cb(const char *name, const uint8_t *cdata, unsigned cmod
{
struct zip_extract_userdata *data = (struct zip_extract_userdata*)userdata;
- // Extract first ROM that matches our list.
+ // Extract first content that matches our list.
const char *ext = path_get_extension(name);
if (ext && string_list_find_elem(data->ext, ext))